==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/zh/gregorian.js <==
define(
//begin v1.x content
{
	"field-tue-relative+-1": "上周二",
	"field-year": "年",
	"dateFormatItem-yw": "y年第w周",
	"dayPeriods-format-abbr-afternoon1": "中午",
	"dayPeriods-format-abbr-afternoon2": "下午",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "本周三",
	"field-wed-relative+1": "下周三",
	"dateFormatItem-ms": "mm:ss",
	"timeFormat-short": "ah:mm",
	"field-minute": "分钟",
	"field-tue-narrow-relative+0": "本周二",
	"field-tue-narrow-relative+1": "下周二",
	"field-thu-short-relative+0": "本周四",
	"dateTimeFormat-short": "{1} {0}",
	"field-day-relative+0": "今天",
	"field-thu-short-relative+1": "下周四",
	"field-day-relative+1": "明天",
	"field-day-relative+2": "后天",
	"field-wed-narrow-relative+-1": "上周三",
	"field-year-narrow": "年",
	"field-tue-relative+0": "本周二",
	"field-tue-relative+1": "下周二",
	"dayPeriods-format-narrow-am": "上午",
	"field-second-short": "秒",
	"dayPeriods-standAlone-abbr-morning1": "清晨",
	"dayPeriods-standAlone-abbr-morning2": "上午",
	"dateFormatItem-MMMd": "M月d日",
	"dayPeriods-format-narrow-morning1": "清晨",
	"dayPeriods-format-narrow-morning2": "上午",
	"dayPeriods-format-abbr-am": "上午",
	"field-month-relative+0": "本月",
	"field-week-relative+0": "本周",
	"timeFormat-medium": "ah:mm:ss",
	"field-month-relative+1": "下个月",
	"field-week-relative+1": "下周",
	"field-sun-narrow-relative+0": "本周日",
	"field-mon-short-relative+0": "本周一",
	"field-sun-narrow-relative+1": "下周日",
	"field-mon-short-relative+1": "下周一",
	"field-second-relative+0": "现在",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"eraNames": [
		"公元前",
		"公元"
	],
	"dayPeriods-standAlone-abbr-pm": "下午",
	"dateFormatItem-GyMMMEd": "Gy年M月d日E",
	"field-month-short": "月",
	"field-day": "日",
	"dayPeriods-standAlone-wide-night1": "凌晨",
	"field-year-relative+-1": "去年",
	"dayPeriods-format-wide-am": "上午",
	"field-sat-short-relative+-1": "上周六",
	"dayPeriods-format-narrow-afternoon1": "中午",
	"dayPeriods-format-wide-afternoon1": "中午",
	"dayPeriods-format-narrow-afternoon2": "下午",
	"field-hour-relative+0": "这一时间 / 此时",
	"dayPeriods-format-wide-afternoon2": "下午",
	"field-wed-relative+-1": "上周三",
	"dateTimeFormat-medium": "{1} {0}",
	"days-standAlone-narrow": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"field-sat-narrow-relative+-1": "上周六",
	"field-second": "秒",
	"dayPeriods-standAlone-wide-pm": "下午",
	"dateFormatItem-Ehms": "Eah:mm:ss",
	"dateFormat-long": "y年M月d日",
	"dateFormatItem-GyMMMd": "Gy年M月d日",
	"dayPeriods-standAlone-abbr-midnight": "午夜",
	"field-quarter": "季度",
	"field-week-short": "周",
	"dayPeriods-format-narrow-midnight": "午夜",
	"dateFormatItem-yMMMEd": "y年M月d日E",
	"quarters-standAlone-wide": [
		"第一季度",
		"第二季度",
		"第三季度",
		"第四季度"
	],
	"days-format-narrow": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"dayPeriods-format-wide-evening1": "晚上",
	"dateTimeFormats-appendItem-Timezone": "{1}{0}",
	"field-tue-short-relative+0": "本周二",
	"field-tue-short-relative+1": "下周二",
	"field-mon-relative+-1": "上周一",
	"dateFormatItem-GyMMM": "Gy年M月",
	"field-month": "月",
	"dayPeriods-standAlone-abbr-night1": "凌晨",
	"field-day-narrow": "日",
	"dayPeriods-standAlone-narrow-afternoon1": "中午",
	"dayPeriods-standAlone-narrow-afternoon2": "下午",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "分",
	"field-dayperiod": "上午/下午",
	"field-sat-short-relative+0": "本周六",
	"field-sat-short-relative+1": "下周六",
	"dayPeriods-format-narrow-pm": "下午",
	"dateFormat-medium": "y年M月d日",
	"eraAbbr": [
		"公元前",
		"公元"
	],
	"quarters-standAlone-abbr": [
		"1季度",
		"2季度",
		"3季度",
		"4季度"
	],
	"dayPeriods-format-abbr-pm": "下午",
	"field-second-narrow": "秒",
	"dayPeriods-standAlone-narrow-night1": "凌晨",
	"field-mon-relative+0": "本周一",
	"field-year-short": "年",
	"field-mon-relative+1": "下周一",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"dayPeriods-format-wide-morning1": "清晨",
	"dayPeriods-format-wide-morning2": "上午",
	"field-quarter-relative+-1": "上季度",
	"dayPeriods-standAlone-narrow-am": "上午",
	"days-format-short": [
		"周日",
		"周一",
		"周二",
		"周三",
		"周四",
		"周五",
		"周六"
	],
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"dayPeriods-format-wide-pm": "下午",
	"field-sat-relative+-1": "上周六",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "M/d",
	"field-hour": "小时",
	"dateFormatItem-yQQQQ": "y年第Q季度",
	"months-format-wide": [
		"一月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"十二月"
	],
	"dayPeriods-format-wide-night1": "凌晨",
	"dateFormat-full": "y年M月d日EEEE",
	"field-month-relative+-1": "上个月",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-quarter-short": "季",
	"field-sat-narrow-relative+0": "本周六",
	"dateFormatItem-Hmv": "v HH:mm",
	"field-fri-relative+0": "本周五",
	"field-sat-narrow-relative+1": "下周六",
	"field-fri-relative+1": "下周五",
	"field-sun-short-relative+0": "本周日",
	"field-sun-short-relative+1": "下周日",
	"field-week-relative+-1": "上周",
	"dateFormatItem-Ehm": "Eah:mm",
	"months-format-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"dayPeriods-format-wide-midnight": "午夜",
	"field-quarter-relative+0": "本季度",
	"timeFormat-long": "z ah:mm:ss",
	"field-minute-relative+0": "此刻",
	"field-quarter-relative+1": "下季度",
	"field-wed-short-relative+-1": "上周三",
	"dateFormatItem-yMMM": "y年M月",
	"dateFormat-short": "y/M/d",
	"dayPeriods-format-abbr-night1": "凌晨",
	"dateFormatItem-MMMMW": "MMM第W周",
	"field-thu-short-relative+-1": "上周四",
	"days-standAlone-wide": [
		"星期日",
		"星期一",
		"星期二",
		"星期三",
		"星期四",
		"星期五",
		"星期六"
	],
	"field-mon-narrow-relative+-1": "上周一",
	"dateFormatItem-MMMMd": "M月d日",
	"field-thu-narrow-relative+-1": "上周四",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-H": "H时",
	"field-tue-narrow-relative+-1": "上周二",
	"dayPeriods-format-abbr-evening1": "晚上",
	"dayPeriods-standAlone-narrow-pm": "下午",
	"dateFormatItem-M": "M月",
	"months-standAlone-wide": [
		"一月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"十二月"
	],
	"field-wed-short-relative+0": "本周三",
	"field-wed-short-relative+1": "下周三",
	"dateFormatItem-Hmsv": "v HH:mm:ss",
	"field-sun-relative+-1": "上周日",
	"days-standAlone-abbr": [
		"周日",
		"周一",
		"周二",
		"周三",
		"周四",
		"周五",
		"周六"
	],
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-hm": "ah:mm",
	"dateFormatItem-d": "d日",
	"field-weekday": "工作日",
	"dayPeriods-standAlone-wide-evening1": "晚上",
	"field-sat-relative+0": "本周六",
	"dateFormatItem-h": "ah时",
	"field-sat-relative+1": "下周六",
	"months-standAlone-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"dateFormatItem-hmsv": "v ah:mm:ss",
	"dayPeriods-format-abbr-morning1": "清晨",
	"dayPeriods-standAlone-narrow-evening1": "晚上",
	"dateFormatItem-yMM": "y年M月",
	"dayPeriods-format-abbr-morning2": "上午",
	"timeFormat-full": "zzzz ah:mm:ss",
	"dateFormatItem-MEd": "M/dE",
	"dateFormatItem-y": "y年",
	"field-thu-narrow-relative+0": "本周四",
	"field-sun-narrow-relative+-1": "上周日",
	"field-mon-short-relative+-1": "上周一",
	"field-thu-narrow-relative+1": "下周四",
	"field-thu-relative+0": "本周四",
	"dayPeriods-standAlone-abbr-afternoon1": "中午",
	"field-thu-relative+1": "下周四",
	"dayPeriods-standAlone-abbr-afternoon2": "下午",
	"dateFormatItem-hms": "ah:mm:ss",
	"field-fri-short-relative+-1": "上周五",
	"dateFormatItem-hmv": "v ah:mm",
	"field-thu-relative+-1": "上周四",
	"dateFormatItem-yMd": "y/M/d",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-week": "周",
	"quarters-format-wide": [
		"第一季度",
		"第二季度",
		"第三季度",
		"第四季度"
	],
	"dateFormatItem-Ed": "d日E",
	"field-wed-narrow-relative+0": "本周三",
	"field-wed-narrow-relative+1": "下周三",
	"dayPeriods-standAlone-wide-morning1": "早上",
	"dayPeriods-standAlone-wide-morning2": "上午",
	"field-fri-short-relative+0": "本周五",
	"field-fri-short-relative+1": "下周五",
	"days-standAlone-short": [
		"周日",
		"周一",
		"周二",
		"周三",
		"周四",
		"周五",
		"周六"
	],
	"dayPeriods-standAlone-narrow-morning1": "早上",
	"dayPeriods-standAlone-narrow-morning2": "上午",
	"dayPeriods-format-abbr-midnight": "午夜",
	"field-hour-short": "小时",
	"quarters-format-abbr": [
		"1季度",
		"2季度",
		"3季度",
		"4季度"
	],
	"field-month-narrow": "月",
	"field-hour-narrow": "小时",
	"field-fri-narrow-relative+-1": "上周五",
	"field-year-relative+0": "今年",
	"field-year-relative+1": "明年",
	"field-fri-relative+-1": "上周五",
	"eraNarrow": [
		"公元前",
		"公元"
	],
	"field-tue-short-relative+-1": "上周二",
	"field-minute-narrow": "分",
	"dayPeriods-standAlone-wide-afternoon1": "中午",
	"dateFormatItem-yQQQ": "y年第Q季度",
	"days-format-wide": [
		"星期日",
		"星期一",
		"星期二",
		"星期三",
		"星期四",
		"星期五",
		"星期六"
	],
	"dayPeriods-standAlone-wide-afternoon2": "下午",
	"field-mon-narrow-relative+0": "本周一",
	"dateFormatItem-EHm": "EHH:mm",
	"field-mon-narrow-relative+1": "下周一",
	"dayPeriods-standAlone-wide-midnight": "午夜",
	"dateFormatItem-yM": "y年M月",
	"field-zone": "时区",
	"dateFormatItem-yMMMM": "y年M月",
	"dateFormatItem-MMMEd": "M月d日E",
	"dateFormatItem-EHms": "EHH:mm:ss",
	"dateFormatItem-yMEd": "y/M/dE",
	"dayPeriods-standAlone-narrow-midnight": "午夜",
	"field-quarter-narrow": "季",
	"dayPeriods-standAlone-abbr-am": "上午",
	"field-day-relative+-1": "昨天",
	"field-sun-short-relative+-1": "上周日",
	"field-day-relative+-2": "前天",
	"dayPeriods-format-narrow-night1": "凌晨",
	"days-format-abbr": [
		"周日",
		"周一",
		"周二",
		"周三",
		"周四",
		"周五",
		"周六"
	],
	"dateFormatItem-MMdd": "MM/dd",
	"field-sun-relative+0": "本周日",
	"field-sun-relative+1": "下周日",
	"dateFormatItem-yMMMd": "y年M月d日",
	"dateFormatItem-Gy": "Gy年",
	"field-era": "纪元",
	"field-week-narrow": "周",
	"field-day-short": "日",
	"dayPeriods-standAlone-abbr-evening1": "晚上",
	"field-fri-narrow-relative+0": "本周五",
	"dayPeriods-format-narrow-evening1": "晚上",
	"field-fri-narrow-relative+1": "下周五",
	"dayPeriods-standAlone-wide-am": "上午"
}
//end v1.x content
);

==> dojo_1.17.2+dfsg1.orig.tar.xz: dojo-release-1.17.2-src/dojo/cldr/nls/zh/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-yMMMM": "y年M月",
	"field-thu-narrow-relative+0": "本周四",
	"field-thu-narrow-relative+1": "下周四",
	"field-sun-narrow-relative+0": "本周日",
	"field-sun-narrow-relative+1": "下周日",
	"months-format-wide": [
		"一月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"十二月"
	],
	"dayPeriods-standAlone-abbr-pm": "下午",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-fri-narrow-relative+0": "本周五",
	"field-fri-narrow-relative+1": "下周五",
	"eraNarrow": [
		"公元前",
		"公元"
	],
	"dateFormatItem-Hmv": "v HH:mm",
	"dateFormatItem-hmsv": "v ah:mm:ss",
	"dateFormatItem-yMMMd": "y年M月d日",
	"dayPeriods-format-abbr-night1": "凌晨",
	"dayPeriods-format-narrow-evening1": "晚上",
	"days-standAlone-narrow": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"days-standAlone-wide": [
		"星期日",
		"星期一",
		"星期二",
		"星期三",
		"星期四",
		"星期五",
		"星期六"
	],
	"dayPeriods-format-abbr-afternoon1": "中午",
	"dayPeriods-format-wide-evening1": "晚上",
	"dayPeriods-format-abbr-afternoon2": "下午",
	"dateFormatItem-Ehm": "Eah:mm",
	"dateTimeFormats-appendItem-Timezone": "{1}{0}",
	"field-wed-narrow-relative+-1": "上周三",
	"dayPeriods-standAlone-wide-evening1": "晚上",
	"field-minute-narrow-relative+0": "此刻",
	"days-format-wide": [
		"星期日",
		"星期一",
		"星期二",
		"星期三",
		"星期四",
		"星期五",
		"星期六"
	],
	"dateFormatItem-yMM": "y年M月",
	"field-month-short-relative+0": "本月",
	"field-month-short-relative+1": "下个月",
	"dateFormatItem-Ehms": "Eah:mm:ss",
	"dayPeriods-standAlone-narrow-evening1": "晚上",
	"dayPeriods-standAlone-abbr-afternoon1": "中午",
	"dayPeriods-standAlone-abbr-afternoon2": "下午",
	"field-thu-relative+0": "本周四",
	"dayPeriods-standAlone-abbr-night1": "凌晨",
	"field-thu-relative+1": "下周四",
	"dayPeriods-format-wide-am": "上午",
	"field-fri-relative+0": "本周五",
	"field-fri-relative+1": "下周五",
	"dateFormatItem-yMd": "y/M/d",
	"field-thu-narrow-relative+-1": "上周四",
	"field-quarter-relative+0": "本季度",
	"field-quarter-relative+1": "下季度",
	"field-sun-short-relative+0": "本周日",
	"timeFormat-short": "ah:mm",
	"field-sun-short-relative+1": "下周日",
	"dateFormatItem-hms": "ah:mm:ss",
	"dayPeriods-format-narrow-afternoon1": "中午",
	"dateFormatItem-Md": "M/d",
	"dayPeriods-format-narrow-afternoon2": "下午",
	"dateFormatItem-Hmsv": "v HH:mm:ss",
	"dateFormatItem-hmv": "v ah:mm",
	"field-week-narrow": "周",
	"field-hour-relative+0": "这一时间 / 此时",
	"field-day-relative+-1": "昨天",
	"field-day-relative+-2": "前天",
	"field-mon-narrow-relative+-1": "上周一",
	"field-minute-narrow": "分",
	"field-thu-short-relative+0": "本周四",
	"field-mon-relative+0": "本周一",
	"field-thu-short-relative+1": "下周四",
	"field-mon-relative+1": "下周一",
	"field-day-narrow-relative+0": "今天",
	"field-era-short": "纪元",
	"field-day-narrow-relative+1": "明天",
	"field-sat-narrow-relative+0": "本周六",
	"field-day-narrow-relative+2": "后天",
	"timeFormat-long": "z ah:mm:ss",
	"field-sat-narrow-relative+1": "下周六",
	"field-week-narrow-relative+0": "本周",
	"field-week-narrow-relative+1": "下周",
	"field-hour-short-relative+0": "这一时间 / 此时",
	"field-wed-narrow-relative+0": "本周三",
	"field-wed-narrow-relative+1": "下周三",
	"field-month": "月",
	"months-standAlone-wide": [
		"一月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"十二月"
	],
	"field-weekday-narrow": "工作日",
	"dayPeriods-standAlone-narrow-afternoon1": "中午",
	"dayPeriods-standAlone-narrow-afternoon2": "下午",
	"field-year-relative+0": "今年",
	"field-year-relative+1": "明年",
	"dayPeriods-format-abbr-evening1": "晚上",
	"dayPeriods-format-narrow-midnight": "午夜",
	"dayPeriods-format-wide-midnight": "午夜",
	"field-tue-relative+0": "本周二",
	"field-tue-relative+1": "下周二",
	"dayPeriods-standAlone-abbr-evening1": "晚上",
	"field-minute-short-relative+0": "此刻",
	"dateFormatItem-hm": "ah:mm",
	"dayPeriods-standAlone-wide-midnight": "午夜",
	"field-year-narrow": "年",
	"field-tue-short-relative+0": "本周二",
	"dayPeriods-standAlone-narrow-midnight": "午夜",
	"field-tue-short-relative+1": "下周二",
	"field-tue-narrow-relative+0": "本周二",
	"field-tue-narrow-relative+1": "下周二",
	"dateTimeFormat-full": "{1}{0}",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-EBhm": "EBh:mm",
	"dateFormatItem-H": "H时",
	"field-wed-relative+0": "本周三",
	"field-wed-relative+1": "下周三",
	"dateFormatItem-M": "M月",
	"field-wed-short-relative+0": "本周三",
	"field-fri-short-relative+0": "本周五",
	"field-wed-short-relative+1": "下周三",
	"field-fri-short-relative+1": "下周五",
	"field-weekOfMonth-short": "月中周",
	"field-quarter-short-relative+-1": "上季度",
	"field-year-short-relative+-1": "去年",
	"dateFormatItem-Bhm": "Bh:mm",
	"dayPeriods-format-wide-night1": "凌晨",
	"dateTimeFormat-medium": "{1}{0}",
	"field-quarter-narrow-relative+-1": "上季度",
	"dateFormatItem-d": "d日",
	"dayPeriods-format-abbr-pm": "下午",
	"dateFormatItem-h": "ah时",
	"quarters-standAlone-wide": [
		"第一季度",
		"第二季度",
		"第三季度",
		"第四季度"
	],
	"field-weekOfMonth-narrow": "月中周",
	"dateFormatItem-y": "y年",
	"field-minute-relative+0": "此刻",
	"field-year-short-relative+0": "今年",
	"dateFormatItem-EBhms": "EBh:mm:ss",
	"field-year-short-relative+1": "明年",
	"field-weekday": "工作日",
	"dayPeriods-format-narrow-pm": "下午",
	"field-tue-narrow-relative+-1": "上周二",
	"dateFormatItem-yMEd": "y/M/dE",
	"dayPeriods-standAlone-wide-night1": "凌晨",
	"field-year-narrow-relative+-1": "去年",
	"field-sat-relative+-1": "上周六",
	"dayPeriods-format-abbr-midnight": "午夜",
	"dayPeriods-format-narrow-morning1": "早上",
	"dayPeriods-format-narrow-morning2": "上午",
	"dayPeriods-format-wide-morning1": "清晨",
	"dayPeriods-format-wide-morning2": "上午",
	"dayPeriods-standAlone-abbr-midnight": "午夜",
	"dayPeriods-standAlone-narrow-pm": "下午",
	"dayPeriods-standAlone-wide-morning1": "早上",
	"field-mon-narrow-relative+0": "本周一",
	"dayPeriods-standAlone-wide-morning2": "上午",
	"field-mon-narrow-relative+1": "下周一",
	"field-second": "秒",
	"dateFormatItem-yMMMEd": "y年M月d日E",
	"field-year-relative+-1": "去年",
	"field-weekdayOfMonth-short": "月中日",
	"dateFormat-short": "y/M/d",
	"eraNames": [
		"公元前",
		"公元"
	],
	"field-second-short": "秒",
	"field-thu-short-relative+-1": "上周四",
	"field-zone": "时区",
	"field-dayperiod-narrow": "上午/下午",
	"field-sun-short-relative+-1": "上周日",
	"dayPeriods-standAlone-narrow-morning1": "早上",
	"dayPeriods-standAlone-narrow-morning2": "上午",
	"eraAbbr": [
		"公元前",
		"公元"
	],
	"field-week-short": "周",
	"dayPeriods-standAlone-abbr-am": "上午",
	"dayPeriods-standAlone-wide-pm": "下午",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+0": "今天",
	"field-day-relative+1": "明天",
	"field-day-relative+2": "后天",
	"field-day-short-relative+0": "今天",
	"field-dayOfYear-short": "年中日",
	"field-day-short-relative+1": "明天",
	"dateFormat-long": "y年M月d日",
	"field-day-short-relative+2": "后天",
	"field-sun-narrow-relative+-1": "上周日",
	"field-second-relative+0": "现在",
	"field-quarter-relative+-1": "上季度",
	"dayPeriods-format-narrow-night1": "凌晨",
	"quarters-format-abbr": [
		"1季度",
		"2季度",
		"3季度",
		"4季度"
	],
	"dayPeriods-standAlone-narrow-night1": "凌晨",
	"field-week-relative+-1": "上周",
	"dayPeriods-format-abbr-morning1": "早上",
	"field-month-relative+-1": "上个月",
	"dayPeriods-format-abbr-morning2": "上午",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-year": "年",
	"field-era": "纪元",
	"dayPeriods-standAlone-abbr-morning1": "早上",
	"dayPeriods-standAlone-abbr-morning2": "上午",
	"days-standAlone-short": [
		"周日",
		"周一",
		"周二",
		"周三",
		"周四",
		"周五",
		"周六"
	],
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"dateFormatItem-yQQQQ": "y年第Q季度",
	"field-day-short-relative+-1": "昨天",
	"field-day-short-relative+-2": "前天",
	"dateFormatItem-GyMMM": "Gy年M月",
	"timeFormat-full": "zzzz ah:mm:ss",
	"dateFormatItem-Bhms": "Bh:mm:ss",
	"field-hour": "小时",
	"field-dayOfYear-narrow": "年中日",
	"field-second-narrow-relative+0": "现在",
	"field-quarter": "季度",
	"field-month-narrow-relative+0": "本月",
	"field-month-narrow-relative+1": "下个月",
	"dateFormatItem-MMdd": "MM/dd",
	"field-day": "日",
	"field-mon-relative+-1": "上周一",
	"field-dayOfYear": "年中日",
	"dateFormat-medium": "y年M月d日",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-yMMM": "y年M月",
	"dateFormatItem-GyMMMd": "Gy年M月d日",
	"dateFormatItem-MEd": "M/dE",
	"field-tue-short-relative+-1": "上周二",
	"field-year-short": "年",
	"field-month-short": "月",
	"dateFormatItem-MMMEd": "M月d日E",
	"dayPeriods-format-wide-afternoon1": "中午",
	"dateFormatItem-MMMd": "M月d日",
	"dayPeriods-format-wide-afternoon2": "下午",
	"dateFormatItem-Bh": "Bh时",
	"months-format-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"dayPeriods-format-abbr-am": "上午",
	"field-sat-relative+0": "本周六",
	"field-sat-relative+1": "下周六",
	"dayPeriods-format-wide-pm": "下午",
	"days-standAlone-abbr": [
		"周日",
		"周一",
		"周二",
		"周三",
		"周四",
		"周五",
		"周六"
	],
	"field-zone-short": "时区",
	"field-week-short-relative+0": "本周",
	"field-week-short-relative+1": "下周",
	"dayPeriods-standAlone-wide-afternoon1": "中午",
	"dayPeriods-standAlone-wide-afternoon2": "下午",
	"field-fri-short-relative+-1": "上周五",
	"field-month-narrow": "月",
	"dayPeriods-format-narrow-am": "上午",
	"field-month-narrow-relative+-1": "上个月",
	"days-format-abbr": [
		"周日",
		"周一",
		"周二",
		"周三",
		"周四",
		"周五",
		"周六"
	],
	"field-weekday-short": "工作日",
	"field-day-narrow-relative+-1": "昨天",
	"field-day-narrow-relative+-2": "前天",
	"field-quarter-short": "季",
	"days-format-short": [
		"周日",
		"周一",
		"周二",
		"周三",
		"周四",
		"周五",
		"周六"
	],
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"days-format-narrow": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"dateFormatItem-EHm": "EHH:mm",
	"field-quarter-narrow": "季",
	"field-mon-short-relative+0": "本周一",
	"field-mon-short-relative+1": "下周一",
	"field-dayperiod-short": "上午/下午",
	"dayPeriods-standAlone-narrow-am": "上午",
	"field-week-narrow-relative+-1": "上周",
	"field-thu-relative+-1": "上周四",
	"field-fri-narrow-relative+-1": "上周五",
	"field-mon-short-relative+-1": "上周一",
	"timeFormat-medium": "ah:mm:ss",
	"field-quarter-short-relative+0": "本季度",
	"field-quarter-short-relative+1": "下季度",
	"dateFormatItem-Ed": "d日E",
	"field-wed-relative+-1": "上周三",
	"field-weekOfMonth": "月中周",
	"field-weekdayOfMonth-narrow": "月中日",
	"dayPeriods-standAlone-wide-am": "上午",
	"dateFormatItem-yQQQ": "y年第Q季度",
	"field-fri-relative+-1": "上周五",
	"field-minute": "分钟",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-second-short-relative+0": "现在",
	"quarters-format-wide": [
		"第一季度",
		"第二季度",
		"第三季度",
		"第四季度"
	],
	"field-day-short": "日",
	"field-dayperiod": "上午/下午",
	"field-hour-short": "小时",
	"months-standAlone-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"field-month-relative+0": "本月",
	"field-second-narrow": "秒",
	"field-month-relative+1": "下个月",
	"dateFormat-full": "y年M月d日EEEE",
	"field-era-narrow": "纪元",
	"field-sat-short-relative+-1": "上周六",
	"field-week-short-relative+-1": "上周",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-yM": "y年M月",
	"field-sun-relative+-1": "上周日",
	"field-wed-short-relative+-1": "上周三",
	"field-weekdayOfMonth": "月中日",
	"field-quarter-narrow-relative+0": "本季度",
	"dateFormatItem-GyMMMEd": "Gy年M月d日E",
	"field-quarter-narrow-relative+1": "下季度",
	"field-sat-short-relative+0": "本周六",
	"field-sat-short-relative+1": "下周六",
	"field-hour-narrow": "小时",
	"field-year-narrow-relative+0": "今年",
	"field-year-narrow-relative+1": "明年",
	"dateFormatItem-Gy": "Gy年",
	"field-zone-narrow": "时区",
	"field-tue-relative+-1": "上周二",
	"field-minute-short": "分",
	"dateFormatItem-yw": "Y年第w周",
	"dateFormatItem-Hm": "HH:mm",
	"field-week-relative+0": "本周",
	"field-week-relative+1": "下周",
	"dateFormatItem-MMM": "LLL",
	"field-sun-relative+0": "本周日",
	"field-sun-relative+1": "下周日",
	"field-sat-narrow-relative+-1": "上周六",
	"quarters-standAlone-abbr": [
		"1季度",
		"2季度",
		"3季度",
		"4季度"
	],
	"dateFormatItem-MMMMW": "MMMM第W周",
	"field-month-short-relative+-1": "上个月",
	"dateFormatItem-EHms": "EHH:mm:ss",
	"dateFormatItem-MMMMd": "M月d日",
	"field-week": "周",
	"field-day-narrow": "日",
	"field-hour-narrow-relative+0": "这一时间 / 此时"
}
//end v1.x content
);
